==> enchant-2.7.1.tar.gz: enchant-2.7.1/doxygen/html/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"structEnchantPwl__TestFixture.html":[1,0,54],
"structEnchantPwl__TestFixture.html#ae0b5f8a07099ab59a10aade0ac66e568":[1,0,54,0],
"structEnchantTestFixture.html":[1,0,56],
"structEnchantTestFixture.html#a03863159457dec328236448dffb7ea49":[1,0,56,1],
"structEnchantTestFixture.html#a18595a2549704cfefbc93a68d072ff27":[1,0,56,2],
"structEnchantTestFixture.html#a39ff2cd4df19d18ee137d7b668728955":[1,0,56,4],
"structEnchantTestFixture.html#a7b37c46e26855e90ad36f7c0ea70fdf1":[1,0,56,3],
"structEnchantTestFixture.html#a8098122af1c4dfee8fc1b6e1b748136e":[1,0,56,5],
"structEnchantTestFixture.html#aa6762a6beac9dd019b12fdff36715222":[1,0,56,0],
"structEnchantTestFixture.html#ac129e24e5593cd52fede2a6398de5e14":[1,0,56,6],
"structProviderDescribe__TestFixture.html":[1,0,59],
"structProviderDescribe__TestFixture.html#a4dd9c394df05d9c7f95b3507381ded46":[1,0,59,0],
"structProviderDescribe__TestFixture.html#acdcd39a9381a8feb62e731281b41e4e7":[1,0,59,1],
"structProviderDescription.html":[1,0,60],
"structProviderDescription.html#a464b45f44d263eb2ce8bd5ddf6489c08":[1,0,60,1],
"structProviderDescription.html#a799b4586be38fa27f2629316a52611fa":[1,0,60,3],
"structProviderDescription.html#a961419849877e2ffb0a3d070ce10fc77":[1,0,60,0],
"structProviderDescription.html#a998e2c15a06c2d0955e5be557bd7f8be":[1,0,60,4],
"structProviderDescription.html#ae6f11aaf57a83f5ac3b7968fe73aab73":[1,0,60,2],
"structProviderDictionaryExists__TestFixture.html":[1,0,61],
"structProviderDictionaryExists__TestFixture.html#aa232ac6e3458919fabdcc42c08a71d0c":[1,0,61,1],
"structProviderDictionaryExists__TestFixture.html#ac8fad4085eee65a2ec302e59984dc079":[1,0,61,0],
"structProviderIdentify__TestFixture.html":[1,0,62],
"structProviderIdentify__TestFixture.html#aacd7d0ec8a06c1483dfc9ffe70d7ebd6":[1,0,62,0],
"structProviderIdentify__TestFixture.html#aed0cefc9fb5d9592571adcb0dfdb7e22":[1,0,62,1],
"structProviderListDicts__TestFixture.html":[1,0,63],
"structProviderListDicts__TestFixture.html#a5adefbda14e4a5ab2b4c11c688e3358d":[1,0,63,0],
"structProviderListDicts__TestFixture.html#a7d6a75b3348b9b8e0263a05ff8132e6e":[1,0,63,2],
"structProviderListDicts__TestFixture.html#ac3d01c01366665382c3768afa8750568":[1,0,63,1],
"structProviderRequestDictionary__TestFixture.html":[1,0,64],
"structProviderRequestDictionary__TestFixture.html#a507b97f0371e629762db43dfd3cb730f":[1,0,64,0],
"structProviderRequestDictionary__TestFixture.html#a5fc187d0d4648ff24b5b5379244d94a0":[1,0,64,2],
"structProviderRequestDictionary__TestFixture.html#aba0eabb6fe6086373c51004bd0486eaa":[1,0,64,1],
"structProvider__TestFixture.html":[1,0,58],
"structProvider__TestFixture.html#a0977a08b06b92436e7b6f7b97e8b5c44":[1,0,58,6],
"structProvider__TestFixture.html#a121f2569ef83d2dec367c905f6f515ce":[1,0,58,1],
"structProvider__TestFixture.html#a2488d639bd70e27ff82dacc079bc49ae":[1,0,58,0],
"structProvider__TestFixture.html#a54407eb8d1acc5b89d000f8cc7de92c9":[1,0,58,5],
"structProvider__TestFixture.html#a55c980baf7a5f18ea96a78bdf5af5950":[1,0,58,3],
"structProvider__TestFixture.html#a5fe06c7aadae233ada28f99c4e2f9f9a":[1,0,58,2],
"structProvider__TestFixture.html#aaa92891b6aea09d220730b0d4f60b084":[1,0,58,4],
"struct__EnchantBroker.html":[1,0,0],
"struct__EnchantBroker.html#a1e9e2151bb451d8b7b3e5c1fe6017ad3":[1,0,0,2],
"struct__EnchantBroker.html#a39b2eb0d057b822a5478fc2fbaeb9aac":[1,0,0,1],
"struct__EnchantBroker.html#a88844610d8bba32f8ee527efdc987d9b":[1,0,0,0],
"struct__EnchantBroker.html#afb3003e5e7ba68c446d0a016e8a8f0f1":[1,0,0,3],
"sys__file_8in_8h_source.html":[2,0,0,3],
"tests_2warn-on-use_8h_source.html":[2,0,1,9],
"unittest__enchant__providers_8h_source.html":[2,0,1,0,0],
"unused-parameter_8h_source.html":[2,0,1,8]
};

==> enchant-2.7.2.tar.gz: enchant-2.7.2/doxygen/html/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"structEnchantGetPrefixDirTestFixture.html#add23ebb2ccd267992f6922d6971eba5d":[1,0,53,0],
"structEnchantPwlWithDictSuggs__TestFixture.html":[1,0,55],
"structEnchantPwlWithDictSuggs__TestFixture.html#ae0b0156964c9de2432e033e300e5c969":[1,0,55,0],
"structEnchantPwl__TestFixture.html":[1,0,54],
"structEnchantPwl__TestFixture.html#ae0b5f8a07099ab59a10aade0ac66e568":[1,0,54,0],
"structEnchantTestFixture.html":[1,0,56],
"structEnchantTestFixture.html#a03863159457dec328236448dffb7ea49":[1,0,56,1],
"structEnchantTestFixture.html#a18595a2549704cfefbc93a68d072ff27":[1,0,56,2],
"structEnchantTestFixture.html#a39ff2cd4df19d18ee137d7b668728955":[1,0,56,4],
"structEnchantTestFixture.html#a7b37c46e26855e90ad36f7c0ea70fdf1":[1,0,56,3],
"structEnchantTestFixture.html#a8098122af1c4dfee8fc1b6e1b748136e":[1,0,56,5],
"structEnchantTestFixture.html#aa6762a6beac9dd019b12fdff36715222":[1,0,56,0],
"structEnchantTestFixture.html#ac129e24e5593cd52fede2a6398de5e14":[1,0,56,6],
"structProviderDescribe__TestFixture.html":[1,0,59],
"structProviderDescribe__TestFixture.html#a4dd9c394df05d9c7f95b3507381ded46":[1,0,59,0],
"structProviderDescribe__TestFixture.html#acdcd39a9381a8feb62e731281b41e4e7":[1,0,59,1],
"structProviderDescription.html":[1,0,60],
"structProviderDescription.html#a464b45f44d263eb2ce8bd5ddf6489c08":[1,0,60,1],
"structProviderDescription.html#a799b4586be38fa27f2629316a52611fa":[1,0,60,3],
"structProviderDescription.html#a961419849877e2ffb0a3d070ce10fc77":[1,0,60,0],
"structProviderDescription.html#a998e2c15a06c2d0955e5be557bd7f8be":[1,0,60,4],
"structProviderDescription.html#ae6f11aaf57a83f5ac3b7968fe73aab73":[1,0,60,2],
"structProviderDictionaryExists__TestFixture.html":[1,0,61],
"structProviderDictionaryExists__TestFixture.html#aa232ac6e3458919fabdcc42c08a71d0c":[1,0,61,1],
"structProviderDictionaryExists__TestFixture.html#ac8fad4085eee65a2ec302e59984dc079":[1,0,61,0],
"structProviderIdentify__TestFixture.html":[1,0,62],
"structProviderIdentify__TestFixture.html#aacd7d0ec8a06c1483dfc9ffe70d7ebd6":[1,0,62,0],
"structProviderIdentify__TestFixture.html#aed0cefc9fb5d9592571adcb0dfdb7e22":[1,0,62,1],
"structProviderListDicts__TestFixture.html":[1,0,63],
"structProviderListDicts__TestFixture.html#a5adefbda14e4a5ab2b4c11c688e3358d":[1,0,63,0],
"structProviderListDicts__TestFixture.html#a7d6a75b3348b9b8e0263a05ff8132e6e":[1,0,63,2],
"structProviderListDicts__TestFixture.html#ac3d01c01366665382c3768afa8750568":[1,0,63,1],
"structProviderRequestDictionary__TestFixture.html":[1,0,64],
"structProviderRequestDictionary__TestFixture.html#a507b97f0371e629762db43dfd3cb730f":[1,0,64,0],
"structProviderRequestDictionary__TestFixture.html#a5fc187d0d4648ff24b5b5379244d94a0":[1,0,64,2],
"structProviderRequestDictionary__TestFixture.html#aba0eabb6fe6086373c51004bd0486eaa":[1,0,64,1],
"structProvider__TestFixture.html":[1,0,58],
"structProvider__TestFixture.html#a0977a08b06b92436e7b6f7b97e8b5c44":[1,0,58,6],
"structProvider__TestFixture.html#a121f2569ef83d2dec367c905f6f515ce":[1,0,58,1],
"structProvider__TestFixture.html#a2488d639bd70e27ff82dacc079bc49ae":[1,0,58,0],
"structProvider__TestFixture.html#a54407eb8d1acc5b89d000f8cc7de92c9":[1,0,58,5],
"structProvider__TestFixture.html#a55c980baf7a5f18ea96a78bdf5af5950":[1,0,58,3],
"structProvider__TestFixture.html#a5fe06c7aadae233ada28f99c4e2f9f9a":[1,0,58,2],
"structProvider__TestFixture.html#aaa92891b6aea09d220730b0d4f60b084":[1,0,58,4],
"struct__EnchantBroker.html":[1,0,0],
"struct__EnchantBroker.html#a1e9e2151bb451d8b7b3e5c1fe6017ad3":[1,0,0,2],
"struct__EnchantBroker.html#a39b2eb0d057b822a5478fc2fbaeb9aac":[1,0,0,1],
"struct__EnchantBroker.html#a88844610d8bba32f8ee527efdc987d9b":[1,0,0,0],
"struct__EnchantBroker.html#afb3003e5e7ba68c446d0a016e8a8f0f1":[1,0,0,3],
"sys__file_8in_8h_source.html":[2,0,0,5],
"tests_2warn-on-use_8h_source.html":[2,0,1,9],
"unittest__enchant__providers_8h_source.html":[2,0,1,0,0],
"unused-parameter_8h_source.html":[2,0,1,8]
};
